@@ -2,26 +2,16 @@ from __future__ import with_statement
 
 import os
 import abc
-import base64
 import configparser
+from base64 import encodebytes, decodebytes
 
 from keyring.errors import PasswordDeleteError
 from keyring.backend import KeyringBackend
 from keyring.util import platform_, properties
 from .escape import escape as escape_for_ini
 
-try:
-    encodebytes = base64.encodebytes
-except AttributeError:  # pragma: no cover
-    encodebytes = base64.encodestring
 
-try:
-    decodebytes = base64.decodebytes
-except AttributeError:  # pragma: no cover
-    decodebytes = base64.decodestring
-
-
-class FileBacked(object):
+class FileBacked:
     @abc.abstractproperty
     def filename(self):
         """
@@ -122,8 +112,7 @@ class Keyring(FileBacked, KeyringBackend):
         return password
 
     def set_password(self, service, username, password):
-        """Write the password in the file.
-        """
+        """Write the password in the file."""
         if not username:
             # https://github.com/jaraco/keyrings.alt/issues/21
             raise ValueError("Username cannot be blank.")
@@ -138,8 +127,7 @@ class Keyring(FileBacked, KeyringBackend):
         self._write_config_value(service, username, password_base64)
 
     def _generate_assoc(self, service, username):
-        """Generate tamper resistant bytestring of associated data
-        """
+        """Generate tamper resistant bytestring of associated data"""
         return (escape_for_ini(service) + r'\0' + escape_for_ini(username)).encode()
 
     def _write_config_value(self, service, key, value):
@@ -179,8 +167,7 @@ class Keyring(FileBacked, KeyringBackend):
             os.chmod(self.file_path, user_read_write)
 
     def delete_password(self, service, username):
-        """Delete the password for the username of the service.
-        """
+        """Delete the password for the username of the service."""
         service = escape_for_ini(service)
         username = escape_for_ini(username)
         config = configparser.RawConfigParser()
